glb_stream library
A pure-Dart streaming parser for the glTF 2.0 binary container (.glb) format.
See the Khronos GLB specification.
Classes
- GlbBinaryChunkData
- A slice of the binary chunk emitted as bytes arrive on the input stream.
- GlbEvent
- Events emitted by GlbStreamParser.parse as a GLB byte stream is consumed.
- GlbHeader
- The 12-byte GLB header parsed from the start of the stream.
- GlbJsonChunk
- The decoded JSON chunk — the glTF document.
- GlbStreamParser
- Streaming parser for the glTF 2.0 binary container (.glb) format.
Exceptions / Errors
- GlbParseException
- Thrown when the input stream is not a valid GLB.